package betterquesting.client.gui2.editors.nbt;

import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api.utils.JsonHelper;
import betterquesting.api.utils.NBTConverter;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.utils.QuestTranslation;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.entity.passive.EntityPig;
import net.minecraft.init.Blocks;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagByte;
import net.minecraft.nbt.NBTTagByteArray;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagDouble;
import net.minecraft.nbt.NBTTagFloat;
import net.minecraft.nbt.NBTTagInt;
import net.minecraft.nbt.NBTTagIntArray;
import net.minecraft.nbt.NBTTagList;
import net.minecraft.nbt.NBTTagLong;
import net.minecraft.nbt.NBTTagShort;
import net.minecraft.nbt.NBTTagString;
import net.minecraft.util.EnumChatFormatting;
import net.minecraftforge.fluids.FluidRegistry;
import net.minecraftforge.fluids.FluidStack;
import org.lwjgl.input.Keyboard;
import org.lwjgl.util.vector.Vector4f;

/* loaded from: betterquesting_client_gui2_editors_nbt.jar:betterquesting/client/gui2/editors/nbt/GuiNbtAdd.class */
public class GuiNbtAdd extends GuiScreenCanvas implements IPEventListener, IVolatileScreen {
    private final NBTBase nbt;
    private final int index;
    private PanelTextField<String> flKey;
    private final List<PanelButtonStorage<NBTBase>> options;
    private NBTBase selected;
    private PanelButton btnConfirm;

    public GuiNbtAdd(GuiScreen parent, NBTTagCompound compoundTag) {
        super(parent);
        this.options = new ArrayList();
        this.selected = null;
        this.nbt = compoundTag;
        this.index = -1;
    }

    public GuiNbtAdd(GuiScreen parent, NBTTagList list, int index) {
        super(parent);
        this.options = new ArrayList();
        this.selected = null;
        this.nbt = list;
        this.index = index;
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 100, 16, 0), 0, QuestTranslation.translate("gui.cancel", new Object[0])));
        this.btnConfirm = new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -16, 100, 16, 0), 1, QuestTranslation.translate("gui.done", new Object[0]));
        cvBackground.addPanel(this.btnConfirm);
        PanelTextBox panTxt = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.json_add", new Object[0])).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        if (this.nbt.func_74732_a() == 10) {
            this.btnConfirm.setActive(false);
            PanelTextBox txKeyTitle = new PanelTextBox(new GuiTransform(GuiAlign.TOP_CENTER, -100, 36, 200, 12, 0), EnumChatFormatting.RED + QuestTranslation.translate("betterquesting.gui.no_key", new Object[0]));
            txKeyTitle.setColor(PresetColor.TEXT_MAIN.getColor());
            cvBackground.addPanel(txKeyTitle);
            this.flKey = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_CENTER, -100, 48, 200, 16, 0), "", FieldFilterString.INSTANCE);
            cvBackground.addPanel(this.flKey);
            this.flKey.setCallback(value -> {
                if (value.isEmpty()) {
                    txKeyTitle.setText(EnumChatFormatting.RED + QuestTranslation.translate("betterquesting.gui.no_key", new Object[0]));
                } else if (this.nbt.func_74764_b(value)) {
                    txKeyTitle.setText(EnumChatFormatting.RED + QuestTranslation.translate("betterquesting.gui.duplicate_key", new Object[0]));
                } else {
                    txKeyTitle.setText(QuestTranslation.translate("betterquesting.gui.key", new Object[0]));
                }
                updateConfirm();
            });
        }
        this.options.clear();
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, 0 * 16, 100, 16, 0), 2, QuestTranslation.translate("betterquesting.btn.item", new Object[0]), JsonHelper.ItemStackToJson(new BigItemStack(Blocks.field_150348_b), new NBTTagCompound())));
        int n = 0 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 100, 0 * 16, 92, 16, 0), 2, QuestTranslation.translate("betterquesting.btn.fluid", new Object[0]), JsonHelper.FluidStackToJson(new FluidStack(FluidRegistry.WATER, 1000), new NBTTagCompound())));
        int n2 = n + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n * 16, 192, 16, 0), 2, QuestTranslation.translate("betterquesting.btn.entity", new Object[0]), JsonHelper.EntityToJson(new EntityPig(this.field_146297_k.field_71441_e), new NBTTagCompound())));
        int n3 = n2 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n2 * 16, 192, 16, 0), 2, NBTTagString.class.getSimpleName(), new NBTTagString("")));
        int n4 = n3 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n3 * 16, 192, 16, 0), 2, NBTTagCompound.class.getSimpleName(), new NBTTagCompound()));
        int n5 = n4 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n4 * 16, 192, 16, 0), 2, NBTTagList.class.getSimpleName(), new NBTTagList()));
        int n6 = n5 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n5 * 16, 192, 16, 0), 2, NBTTagByte.class.getSimpleName(), new NBTTagByte((byte) 0)));
        int n7 = n6 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n6 * 16, 192, 16, 0), 2, NBTTagShort.class.getSimpleName(), new NBTTagShort((short) 0)));
        int n8 = n7 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n7 * 16, 192, 16, 0), 2, NBTTagInt.class.getSimpleName(), new NBTTagInt(0)));
        int n9 = n8 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n8 * 16, 192, 16, 0), 2, NBTTagLong.class.getSimpleName(), new NBTTagLong(0L)));
        int n10 = n9 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n9 * 16, 192, 16, 0), 2, NBTTagFloat.class.getSimpleName(), new NBTTagFloat(0.0f)));
        int n11 = n10 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n10 * 16, 192, 16, 0), 2, NBTTagDouble.class.getSimpleName(), new NBTTagDouble(0.0d)));
        int n12 = n11 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n11 * 16, 192, 16, 0), 2, NBTTagByteArray.class.getSimpleName(), new NBTTagByteArray(new byte[0])));
        int i = n12 + 1;
        this.options.add(new PanelButtonStorage<>(new GuiTransform(GuiAlign.MID_CENTER, 0, n12 * 16, 192, 16, 0), 2, NBTTagIntArray.class.getSimpleName(), new NBTTagIntArray(new int[0])));
        CanvasScrolling cvOptions = new CanvasScrolling(new GuiTransform(new Vector4f(0.5f, 0.0f, 0.5f, 1.0f), new GuiPadding(-100, 64, -92, 32), 0));
        cvBackground.addPanel(cvOptions);
        for (PanelButtonStorage<NBTBase> btn : this.options) {
            cvOptions.addPanel(btn);
        }
        PanelVScrollBar scOptions = new PanelVScrollBar(new GuiTransform(new Vector4f(0.5f, 0.0f, 0.5f, 1.0f), new GuiPadding(92, 64, -100, 32), 0));
        cvBackground.addPanel(scOptions);
        cvOptions.setScrollDriverY(scOptions);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        switch (button.getButtonID()) {
            case 0:
                this.field_146297_k.func_147108_a(this.parent);
                return;
            case 1:
                if (this.selected == null) {
                    return;
                }
                if (this.nbt.func_74732_a() == 10) {
                    this.nbt.func_74782_a((String) this.flKey.getValue(), this.selected);
                } else if (this.nbt.func_74732_a() == 9) {
                    NBTTagList l = this.nbt;
                    if (this.index == l.func_74745_c()) {
                        l.func_74742_a(this.selected);
                    } else {
                        List tagList = NBTConverter.getTagList(l);
                        for (int n = tagList.size() - 1; n >= this.index; n--) {
                            tagList.set(n + 1, tagList.get(n));
                        }
                        tagList.set(this.index, this.selected);
                    }
                }
                this.field_146297_k.func_147108_a(this.parent);
                return;
            case 2:
                this.selected = (NBTBase) button.getStoredValue();
                for (PanelButtonStorage<NBTBase> b : this.options) {
                    b.setActive(true);
                }
                button.setActive(false);
                updateConfirm();
                return;
            default:
                return;
        }
    }

    private void updateConfirm() {
        if (this.flKey == null) {
            this.btnConfirm.setActive(this.selected != null);
        } else if (((String) this.flKey.getValue()).isEmpty() || this.nbt.func_74764_b((String) this.flKey.getValue())) {
            this.btnConfirm.setActive(false);
        } else {
            this.btnConfirm.setActive(this.selected != null);
        }
    }
}
